@@ -1,16 +1,15 @@
 package org.ovirt.vdsm.jsonrpc.client.events;
 
 import java.util.Map;
-
-import org.reactivestreams.Subscriber;
-import org.reactivestreams.Subscription;
+import java.util.concurrent.Flow;
+import java.util.concurrent.Flow.Subscription;
 
 
 /**
  * Subscription id contains &lt;receiver&gt;.&lt;component&gt;.&lt;operation_id&gt;.&lt;unique_id&gt;.
  *
  */
-public abstract class EventSubscriber implements Subscriber<Map<String, Object>> {
+public abstract class EventSubscriber implements Flow.Subscriber<Map<String, Object>> {
 
     private String subscriptionId;
 
@@ -23,26 +22,30 @@ public abstract class EventSubscriber implements Subscriber<Map<String, Object>>
 
     /*
      * (non-Javadoc)
-     * @see org.reactivestreams.Subscriber#onSubscribe(org.reactivestreams.Subscription)
+     * 
+     * @see java.util.concurrent.Flow.Subscriber#onSubscribe(java.util.Flow.Subscription)
      */
     public abstract void onSubscribe(Subscription s);
 
     /*
      * (non-Javadoc)
-     * @see org.reactivestreams.Subscriber#onNext(java.lang.Object)
+     * 
+     * @see java.util.concurrent.Flow.Subscriber#onNext(java.lang.Object)
      */
     public abstract void onNext(Map<String, Object> t);
 
     /*
      * (non-Javadoc)
-     * @see org.reactivestreams.Subscriber#onError(java.lang.Throwable)
+     * 
+     * @see java.util.concurrent.Flow.Subscriber#onError(java.lang.Throwable)
      */
     public abstract void onError(Throwable t);
 
 
     /*
      * (non-Javadoc)
-     * @see org.reactivestreams.Subscriber#onComplete()
+     * 
+     * @see java.util.concurrent.Flow.Subscriber#onComplete()
      */
     public abstract void onComplete();
 
